@@ -1,7 +1,7 @@
 package Perinci::Tx::Manager;
 
-our $DATE = '2015-10-22'; # DATE
-our $VERSION = '0.54'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.55'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,7 +12,7 @@ use Log::Any::IfLOG '$log';
 use DBI;
 use File::Flock::Retry;
 use File::Remove qw(remove);
-use JSON;
+use JSON::MaybeXS;
 use Perinci::Sub::Util qw(err);
 use Scalar::Util qw(blessed);
 use Package::MoreUtil qw(package_exists);
@@ -50,7 +50,7 @@ my $proto_v = 2;
 our $ep = ""; # error prefix
 our $lp = "[tm]"; # log prefix
 
-my $json = JSON->new->allow_nonref;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 # this is used for testing purposes only (e.g. to simulate crash)
 our %_hooks;
@@ -1391,7 +1391,7 @@ Perinci::Tx::Manager - A Rinci transaction manager
 
 =head1 VERSION
 
-This document describes version 0.54 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2015-10-22.
+This document describes version 0.55 of Perinci::Tx::Manager (from Perl distribution Perinci-Tx-Manager), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -1605,19 +1605,13 @@ inconsistent ones (i.e., those with final statuses C<C>, C<U>, C<X>).
 
 Discard (forget) all committed transactions.
 
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
-
-L<Perinci::Access::Schemeless>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Tx-Manager>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Tx-Manager>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Tx-Manager>.
 
 =head1 BUGS
 
@@ -1627,13 +1621,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
+
+L<Perinci::Access::Schemeless>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
